@@ -1,4 +1,4 @@
-random.polychor.pa <- function (nvar = "NULL", n.ss = "NULL", nrep, nstep = "NULL", data.matrix, q.eigen, r.seed = "NULL", diff.fact=FALSE, distr="NULL", comparison = "random", fit.pa=FALSE, print.all=FALSE) 
+random.polychor.pa <- function (nvar = "NULL", n.ss = "NULL", nrep, nstep = "NULL", data.matrix, q.eigen, r.seed = "NULL", diff.fact=FALSE, distr="NULL", comparison = "random", fit.pa=FALSE, print.all=FALSE, continuity=0.0) 
 {
   ### PRELIMINAR CHECK: START
   start.t <- Sys.time()
@@ -106,7 +106,14 @@ random.polychor.pa <- function (nvar = "NULL", n.ss = "NULL", nrep, nstep = "NUL
   else {
     set.seed(r.seed)
   }
-  
+
+  if (continuity == 0.0) {
+    cat("*** correction for continuity set to: 0.0","\n")
+  }
+  else {
+    cat("*** correction for continuity set to: 0.5","\n")
+  }
+    
   nvar <- ncol(data.matrix)
   cat("*** number of variables (cols) in data.matrix:", nvar, "\n")
   flush.console()
@@ -282,7 +289,7 @@ random.polychor.pa <- function (nvar = "NULL", n.ss = "NULL", nrep, nstep = "NUL
         
         for (j in 1:nrep) {
           matrix.3<-sim.random.matrix()
-          f1.poly.cor <- suppressMessages(polychoric(matrix.3, global=FALSE)$rho)   # simulated polychoric corr
+          f1.poly.cor <- suppressMessages(polychoric(matrix.3, global=FALSE, correct=continuity)$rho)   # simulated polychoric corr
           f1.cor <- cor(matrix.3)   # simulated pearson corr
           eigen.data[, j] <- eigen(corFA(f1.poly.cor))$values
           eigen.data1[, j] <- eigen(corFA(f1.cor))$values
@@ -327,7 +334,7 @@ random.polychor.pa <- function (nvar = "NULL", n.ss = "NULL", nrep, nstep = "NUL
         
         for (j in 1:nrep) {
           matrix.3<-sim.random.matrix()
-          f1.poly.cor <- suppressMessages(polychoric(matrix.3, global=FALSE)$rho)   # simulated polychoric corr
+          f1.poly.cor <- suppressMessages(polychoric(matrix.3, global=FALSE, correct=continuity)$rho)   # simulated polychoric corr
           f1.cor <- cor(matrix.3)   # simulated pearson corr
           eigen.data.pca[, j] <- eigen(f1.poly.cor)$values
           eigen.data1.pca[, j] <- eigen(f1.cor)$values
@@ -376,7 +383,7 @@ random.polychor.pa <- function (nvar = "NULL", n.ss = "NULL", nrep, nstep = "NUL
           boot.matrix[,j]<-column[i]
         }
         # cat("\n", "BOOTSTRAP sampled FA eigenvalues from POLYCHORIC correlations", "\n")
-        boot.polyc<-suppressMessages(polychoric(boot.matrix, global=FALSE)$rho) ### polychoric correlation
+        boot.polyc<-suppressMessages(polychoric(boot.matrix, global=FALSE, correct=continuity)$rho) ### polychoric correlation
         eigen.polyc.fa<-eigen(corFA(boot.polyc))$values       ### FA
         return(eigen.polyc.fa)
       }
@@ -388,7 +395,7 @@ random.polychor.pa <- function (nvar = "NULL", n.ss = "NULL", nrep, nstep = "NUL
           boot.matrix[,j]<-column[i]
         }
         # cat("\n", "BOOTSTRAP sampled PCA eigenvalues from POLYCHORIC correlations", "\n")
-        boot.polyc<-suppressMessages(polychoric(boot.matrix, global=FALSE)$rho) ### polychoric correlation
+        boot.polyc<-suppressMessages(polychoric(boot.matrix, global=FALSE, correct=continuity)$rho) ### polychoric correlation
         eigen.polyc.pca<-eigen(boot.polyc)$values             ### PCA
         return(eigen.polyc.pca)
       }
@@ -455,7 +462,7 @@ random.polychor.pa <- function (nvar = "NULL", n.ss = "NULL", nrep, nstep = "NUL
     ###### PUT THE FOLLOWING RESULTS IN A NEW NAMED COMMON MATRIX (COMMON TO RANDOM AND BOOSTRAP)
     
     ### COMPUTING EMPIRICAL CORRELATION MATRICES: START 
-    matrix.cor1 <- suppressMessages(polychoric(data.matrix.sub, global=FALSE)$rho)
+    matrix.cor1 <- suppressMessages(polychoric(data.matrix.sub, global=FALSE, correct=continuity)$rho)
     matrix.cor2 <- cor(data.matrix.sub)
     ### COMPUTING EMPIRICAL CORRELATION MATRICES: END
     ### COMPUTING EMPIRICAL EIGENVALUES FA/PCA RESULTS: START
